@@ -96,7 +96,7 @@ def grid2points(arr, lons, lats, lon_pnts, lat_pnts, order = 1):
     return ndimage.map_coordinates(arr, [map_lats, map_lons], order = order)
 
 def grid2points2(arr, lons, lats, lon_pnts, lat_pnts, missing = -9999, method = 'linear'):
-    arr[np.where(arr == missing)] = np.nan
+    if missing: arr[np.where(arr == missing)] = np.nan
     lonlon, latlat = np.meshgrid(lons, lats)
     data = griddata((latlat.ravel(), lonlon.ravel()), arr.ravel(), (lat_pnts, lon_pnts), method = method)
     return data
@@ -105,7 +105,7 @@ def points2grid(data, lons, lats, missing = -9999, method = 'nearest'):
     uniqueLats = np.unique(lats)
     uniqueLons = np.unique(lons)
 
-    data[np.where(data == missing)] = np.nan
+    if missing: data[np.where(data == missing)] = np.nan
     points = list(zip(lons, lats))
     grid_x, grid_y = np.meshgrid(uniqueLons, uniqueLats)
     arr = griddata(points, data, (grid_x, grid_y), method = method)
